#!/bin/env python
# -*- coding: utf-8 -*- #
# Created And Coded by RC Chuah-(RaynerSec)

# Import Modules
import os
import sys
import argparse

# Main Function
def main():
    # Process Command Line Arguments
    parser = argparse.ArgumentParser(description='Kali-Nethunter-In-Termux Installer', add_help=False)
    parser.add_argument('-f', '--full', action='store_true', help='Install Kali Nethunter In Termux Full Version.')
    parser.add_argument('-m', '--minimal', action='store_true', help='Install Kali Nethunter In Termux Minimal Version.')
    parser.add_argument('-u', '--uninstall', action='store_true', help='Uninstall Kali Nethunter In Termux.')
    parser.add_argument('-h', '--help', action='help', help='Show This Help Message And Exit.')
    # If No Arguments Provided, Display Usage Information
    if len(sys.argv)==1:
      parser.print_help(sys.stderr)
      print("")
      sys.exit(1)
    # Parsing Command Line Arguments
    args = parser.parse_args()
    # Command Line Arguments
    if args.full:
      os.system("cd ${HOME} && curl -fsSL https://bit.do/fNyso | bash && rm -rf ${HOME}/kalifs-armhf-full.tar.xz && rm -rf ${HOME}/kalifs-arm64-full.tar.xz && rm -rf ${HOME}/kalifs-armhf-full.sha512sum && rm -rf ${HOME}/kalifs-arm64-full.sha512sum")
    if args.minimal:
      os.system("cd ${HOME} && curl -fsSL https://bit.do/fNysW | bash && rm -rf ${HOME}/kalifs-armhf-minimal.tar.xz && rm -rf ${HOME}/kalifs-arm64-minimal.tar.xz && rm -rf ${HOME}/kalifs-armhf-minimal.sha512sum && rm -rf ${HOME}/kalifs-arm64-minimal.sha512sum")
    if args.uninstall:
      os.system("rm -rf ${HOME}/kali-arm64 && rm -rf ${HOME}/kali-armhf && rm -rf ${PREFIX}/bin/nh && rm -rf ${PREFIX}/bin/nethunter && sleep 1 && echo [+] Successfully Uninstalled ...")

# Driver Code
if __name__ == "__main__":
    main()



#!/bin/env python

from setuptools import setup

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(name="pymuxkali",
      version="1.2",
      description="This is a python script by which you can install Kali Nethunter (Kali Linux) in your termux application without rooted phone.",
      long_description=long_description,
      long_description_content_type="text/markdown",
      url="https://github.com/rc-chuah/pymuxkali",
      author="RC Chuah",
      author_email="raynersec@gmail.com",
      license="GNU General Public License v3 (GPLv3)",
      keywords=["kali", "kalilinux", "kalinethunter", "infosec", "cybersec", "infosecurity", "cybersecurity"],
      packages=["pymuxkali"],
      entry_points={
          "console_scripts": [
                "pymuxkali = pymuxkali.pymuxkali:main",
          ]
      },
      project_urls={
          "Source": "https://github.com/rc-chuah/pymuxkali",
          "Source": "https://github.com/RaynerSec/pymuxkali",
      },
      classifiers=[
          "Development Status :: 5 - Production/Stable",
          "Environment :: Console",
          "Intended Audience :: Developers",
          "Intended Audience :: Information Technology",
          "Intended Audience :: System Administrators",
          "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
          "Natural Language :: English",
          "Programming Language :: Python",
          "Programming Language :: Python :: 2",
          "Programming Language :: Python :: 3",
          "Operating System :: Android",
          "Topic :: Security",
          "Topic :: Utilities",
      ],
      zip_safe=False
)